@@ -8,4 +8,4 @@ class Exporter:
         df = pd.DataFrame(data = data)
         save_df = df[self.save_col]
         save_df.to_csv(output+'.csv')
-        return df
\ No newline at end of file
+        return save_df
\ No newline at end of file
